The Elm Format Installer
========================

We have a way to use ``npm install elm-format``, however it is often hard to use.
This is an attempt to create a pypi installer so that we can use: ``pip install elm-format`` instead.


Install
-------

.. code-block:: console

    $ pip install elm-format --no-cache-dir
    $ elm-format --help | head -n1
    elm-format 0.8.1
